@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import PoolMeta
 
 
 class Company(metaclass=PoolMeta):
@@ -37,10 +37,3 @@ class Company(metaclass=PoolMeta):
     @staticmethod
     def default_hours_per_work_year():
         return 1920
-
-    @classmethod
-    def write(cls, *args):
-        pool = Pool()
-        User = pool.get('res.user')
-        super(Company, cls).write(*args)
-        User._get_preferences_cache.clear()
